Documentation
¶
Index ¶
- func StringID(input string) uint32
- func Unpack(dat []byte, path string) error
- type DirectoryEntry
- type FileEntry
- type MCPKFileSystem
- type RotorObj
- func (r *RotorObj) Advances()
- func (r *RotorObj) DChar(c byte) byte
- func (r *RotorObj) DRegion(data []byte, doInit bool)
- func (r *RotorObj) DRotors()
- func (r *RotorObj) EChar(p byte) byte
- func (r *RotorObj) ERegion(data []byte, doInit bool)
- func (r *RotorObj) ERotors()
- func (r *RotorObj) Init()
- func (r *RotorObj) MakeIDRotor(rtr []byte)
- func (r *RotorObj) PermuteRotor(e, d []byte)
- func (r *RotorObj) Positions()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StringID ¶
replicates _Z8StringIDPKc https://github.com/elnx/0x9BE74448
Types ¶
type DirectoryEntry ¶
type MCPKFileSystem ¶
type MCPKFileSystem struct {
DirectoryEntryList []DirectoryEntry
FileEntries map[uint32][]FileEntry
// contains filtered or unexported fields
}
I don't want to mess its name with ModCoderPack
func NewMCPKFileSystem ¶
func NewMCPKFileSystem(data []byte) (*MCPKFileSystem, error)
replicates _ZN13MCPFileSystem5_InitEPKc
type RotorObj ¶
type RotorObj struct {
// contains filtered or unexported fields
}
func NewRotorObj ¶
func (*RotorObj) Advances ¶
func (r *RotorObj) Advances()
rtrAdvances sets the number of positions to advance the rotors at a time.
func (*RotorObj) DRegion ¶
rtrDRegion performs a rotor decryption of a byte slice data using the given rotor machine.
func (*RotorObj) DRotors ¶
func (r *RotorObj) DRotors()
rtrDRotors sets the current set of decryption rotors.
func (*RotorObj) ERegion ¶
rtrERegion performs a rotor encryption of a byte slice data using the given rotor machine.
func (*RotorObj) ERotors ¶
func (r *RotorObj) ERotors()
rtrERotors sets the current set of encryption rotors.
func (*RotorObj) Init ¶
func (r *RotorObj) Init()
rtrInit initializes the rotor machine given a key.
func (*RotorObj) MakeIDRotor ¶
rtrMakeIDRotor sets ROTOR to the identity permutation.
func (*RotorObj) PermuteRotor ¶
rtrPermuteRotor permutes the E rotor and makes the D rotor its inverse.